@@ -43,6 +43,7 @@
 #include "QuestsManager.h"
 #include "Configuration.h"
 #include "FogMap.h"
+#include "history.h"
 
 using namespace std;
 
@@ -354,7 +355,7 @@ bool CreateScenario::create(const GameParameters &g)
     if (!setupTemples())
         return false;
     
-    if (!setupRuins())
+    if (!setupRuins(GameScenario::s_play_with_quests))
         return false;
 
     if (!setupSignposts())
@@ -457,12 +458,17 @@ bool CreateScenario::distributePlayers()
             (*cit).setCapital(true);
             skipping = 0;
 
+            History_CityWon *item = new History_CityWon();
+            item->fillData(&*cit);
+            (*pit)->getHistorylist()->push_back(item);
+
             pit++;
             if ((*pit) == pl->getNeutral())
                 pit++;
         }
         else
             (*cit).setPlayer(pl->getNeutral());
+
     }
 
     return true;
@@ -480,7 +486,7 @@ bool CreateScenario::setupCities(bool quick_start)
         // no neutral cities
         // divvy up the neutral cities among other non-neutral players
         int cities_left = clist->size() - plist->size() + 1;
-        int citycount[MAX_PLAYERS];
+        unsigned int citycount[MAX_PLAYERS];
 	memset (citycount, 0, sizeof (citycount));
         Playerlist::iterator pit = plist->begin();
         for (; pit != plist->end(); pit++)
@@ -500,6 +506,9 @@ bool CreateScenario::setupCities(bool quick_start)
                 pos = clist->getFirstCity(p)->getPos();
 	        City *c = clist->getNearestNeutralCity(pos);
                 c->conquer(p);
+                History_CityWon *item = new History_CityWon();
+                item->fillData(c);
+                p->getHistorylist()->push_back(item);
               }
           }
       }
@@ -575,7 +584,7 @@ bool CreateScenario::setupTemples()
     return true;
 }
 
-bool CreateScenario::setupRuins()
+bool CreateScenario::setupRuins(bool strongholds_invisible)
 {
     debug("CreateScenario::setupRuins")
 
@@ -600,17 +609,32 @@ bool CreateScenario::setupRuins()
         int randno = rand() % d_ruinnames.size();
         (*it).setName(d_ruinnames[randno]);
 
+        // set a random ruin type
+        if (rand() % 6 == 0) //one in six ruins is a stronghold
+          {
+            (*it).setType(Ruin::STRONGHOLD);
+            if (strongholds_invisible == true)
+              {
+                (*it).setHidden(true);
+                (*it).setOwner(NULL);
+              }
+          }
+        else
+          (*it).setType(Ruin::RUIN);
+
         //remove the used name
         d_ruinnames[randno] = d_ruinnames[d_ruinnames.size() - 1];
         d_ruinnames.pop_back();
 
-        if (rand() % 20 == 0) //one in twenty ruins is a sage
+        //one in twenty ruins is a sage
+        if (rand() % 20 == 0 && (*it).getType() == Ruin::RUIN) 
           {
             (*it).setSage (true);
             continue;
           }
 
-        if (rand() % 10 == 0) //one in ten doesn't have a guardian
+        //one in ten ruins doesn't have a guardian
+        if (rand() % 10 == 0 && (*it).getType() == Ruin::RUIN) 
           continue;
 
         // and set a guardian
@@ -624,17 +648,12 @@ bool CreateScenario::setupRuins()
             s = new Stack(0, pos);
             
             a = occupants[rand() % occupants.size()];
-            s->push_back(new Army(*a));
+            s->push_back(new Army(*a, p));
             a = 0;
 
             //now mark this stack as guard
             (*it).setOccupant(s);
           }
-        if (rand() % 10 == 0) //one in ten is a hidden ruin
-          {
-            (*it).setHidden(true);
-            (*it).setOwner(NULL);
-          }
     }
 
     return true;
@@ -702,6 +721,12 @@ bool CreateScenario::setupPlayers()
 {
     debug("CreateScenario::setupPlayers")
 
+    Playerlist *plist = Playerlist::getInstance();
+    Playerlist::iterator pit = plist->begin();
+    for (; pit != plist->end(); pit++)
+      {
+	(*pit)->setGold(1000 + ((rand() % 8) * 50));
+      }
     return true;
 }
 
