@@ -371,7 +371,7 @@ Stack* GameMap::addArmy(Location *l, Army *a)
   s = l->addArmy(a);
   if (s)
     return s;
-  return addArmy(l->getPos(), a);
+  return addArmyAtPos(l->getPos(), a);
 }
 
 bool GameMap::isDock(int x, int y)
@@ -458,3 +458,32 @@ void GameMap::calculateBlockedAvenues()
           }
       }
 }
+
+Vector<int> GameMap::findPlantedStandard(Player *p)
+{
+    bool found = false;
+    Vector<int> pos;
+    pos.x = -1;
+    pos.y = -1;
+    for (int x = 0; x < getWidth(); x++)
+      {
+        for (int y = 0; y < getHeight(); y++)
+          {
+            std::list<Item*> items = getTile(x, y)->getItems();
+            for (std::list<Item*>::iterator it = items.begin(); 
+                 it != items.end(); it++)
+              {
+                if ((*it)->isPlantable() && (*it)->getPlantableOwner() == p)
+                  {
+                    pos.x = x;
+                    pos.y = y;
+                    found = true;
+                    break;
+                  }
+              }
+            if (found)
+              break;
+          }
+      }
+  return pos;
+}
