@@ -24,16 +24,19 @@
 struct ArmyCacheItem;
 struct ShipCacheItem;
 struct CityCacheItem;
+struct TowerCacheItem;
 struct TempleCacheItem;
 struct StoneCacheItem;
 struct RoadCacheItem;
 struct BridgeCacheItem;
+struct CursorCacheItem;
 struct FlagCacheItem;
 struct SelectorCacheItem;
 struct ShieldCacheItem;
 struct ProdShieldCacheItem;
 struct MoveBonusCacheItem;
 struct FogCacheItem;
+struct PlantedStandardCacheItem;
 class City;
 
 /** Soliton class for caching army and map images
@@ -67,6 +70,21 @@ class City;
 class GraphicsCache
 {
     public:
+  enum CursorType
+    {
+      POINTER = 0,
+      MAGNIFYING_GLASS,
+      SHIP,
+      ROOK,
+      HAND,
+      TARGET,
+      FEET,
+      RUIN,
+      SWORD,
+      QUESTION,
+      HEART,
+      GOTO_ARROW
+    };
         //! Function for getting/creating the soliton instance.
         static GraphicsCache* getInstance();
 
@@ -98,18 +116,6 @@ class GraphicsCache
         SDL_Surface* getArmyPic(Uint32 armyset, Uint32 army, const Player* p,
                                 int level, const bool* medals);
 
-        /** Function for getting a city picture
-          * 
-          * For simplicity we have extended the basic_image/mask style to
-          * cities as well, since it greatly reduces the number of images.
-          * Use this function solely to get city images, and don't touch the
-          * images!
-          *
-          * @param type         the level of the city; -1 returns the pic for
-          *                     the razed city
-          * @param player       the player owning the city
-          * @return image of the described city
-          */
         SDL_Surface* getTemplePic(int type);
         /** Function for getting a temple picture
           *
@@ -137,6 +143,12 @@ class GraphicsCache
           * @param type         the type of the bridge 0=e/w 1=n/s
           * @return image of the bridge
           */
+        SDL_Surface* getCursorPic(int type);
+        /** Function for getting a cursor picture
+          *
+          * @param type         the type of the cursor 
+          * @return image of the cursor
+          */
         SDL_Surface* getStonePic(int type);
         /** Function for getting a stone picture
           *
@@ -148,7 +160,20 @@ class GraphicsCache
           */
 
         SDL_Surface* getShipPic(const Player* p);
+        SDL_Surface* getPlantedStandardPic(const Player* p);
 
+        /** Function for getting a city picture
+          * 
+          * For simplicity we have extended the basic_image/mask style to
+          * cities as well, since it greatly reduces the number of images.
+          * Use this function solely to get city images, and don't touch the
+          * images!
+          *
+          * @param type         the level of the city; -1 returns the pic for
+          *                     the razed city
+          * @param player       the player owning the city
+          * @return image of the described city
+          */
         SDL_Surface* getCityPic(int type, const Player* p);
         /** Another function for getting a city picture
           *
@@ -160,6 +185,16 @@ class GraphicsCache
           */
         SDL_Surface* getCityPic(const City* city);
 
+        /** Function for getting tower pictures.
+          *
+          * As with the other functions, use solely this function to get the tower 
+          * images. And DON'T modify the images!
+          *
+          * @param p the player for which we want to get the tower
+          * @return image for the tower
+          */
+        SDL_Surface* getTowerPic(const Player *p);
+
         /** Function for getting flag pictures.
           *
           * As with the other functions, use solely this function to get the flag
@@ -198,6 +233,7 @@ class GraphicsCache
         SDL_Surface *getSmallTemplePic();
         SDL_Surface *getSmallRuinExploredPic();
         SDL_Surface* getSmallRuinUnexploredPic();
+        SDL_Surface* getSmallStrongholdUnexploredPic();
 
         /** Function for getting production shield pictures.
           *
@@ -245,6 +281,9 @@ class GraphicsCache
         //! Creates a new bridge picture with the given parameters.
         BridgeCacheItem* addBridgePic(int type);
 
+        //! Creates a new cursor picture with the given parameters.
+        CursorCacheItem* addCursorPic(int type);
+
         //! Creates a new army picture with the given parameters.
         ArmyCacheItem* addArmyPic(Uint32 armyset, Uint32 army, const Player* p,
                                   int level, const bool* medalsbonus);
@@ -252,9 +291,15 @@ class GraphicsCache
         //! Creates a new city picture with the given parameters.
         CityCacheItem* addCityPic(int type, const Player* p);
 
+        //! Creates a new tower picture with the given parameters.
+        TowerCacheItem* addTowerPic(const Player* p);
+
         //! Creates a new ship picture with the given parameters.
         ShipCacheItem* addShipPic(const Player* p);
 
+        //! Creates a new planted standard picture with the given parameters.
+        PlantedStandardCacheItem* addPlantedStandardPic(const Player* p);
+
         //! Creates a new flag picture with the given parameters.
         FlagCacheItem* addFlagPic(int size, const Player* p);
 
@@ -292,12 +337,21 @@ class GraphicsCache
         //! Erases the oldest (least recently requested) bridge cache item.
         void eraseLastBridgeItem();
 
+        //! Erases the oldest (least recently requested) cursor cache item.
+        void eraseLastCursorItem();
+
         //! Erases the oldest (least recently requested) city cache item.
         void eraseLastCityItem();
 
+        //! Erases the oldest (least recently requested) tower cache item.
+        void eraseLastTowerItem();
+
         //! Erases the oldest (least recently requested) ship cache item.
         void eraseLastShipItem();
 
+        //! Erases the oldest planted standard cache item.
+        void eraseLastPlantedStandardItem();
+
         //! Erases the oldest flag cache item
         void eraseLastFlagItem();
 
@@ -313,12 +367,18 @@ class GraphicsCache
         //! Erases the oldest movement bonus cache item
         void eraseLastMoveBonusItem();
 
-        //! Loads the images for the city pictures and their masks.
+        //! Loads the images for the city pictures
         void loadCityPics();
 
+        //! Loads the images for the tower pictures
+        void loadTowerPics();
+
         //! Loads the images for the ship picture and it's mask.
         void loadShipPic();
 
+        //! Loads the images for the planted standard picture and it's mask.
+        void loadPlantedStandardPic();
+
         //! Loads the images for the city pictures.
         void loadTemplePics();
 
@@ -334,6 +394,9 @@ class GraphicsCache
         //! Loads the images for the bridge pictures.
         void loadBridgePics();
 
+        //! Loads the images for the cursor pictures.
+        void loadCursorPics();
+
         //! Loads the images for the flags
         void loadFlags();
 
@@ -355,26 +418,31 @@ class GraphicsCache
         Uint32 d_cachesize;
         std::list<ArmyCacheItem*> d_armylist;
         std::list<CityCacheItem*> d_citylist;
+        std::list<TowerCacheItem*> d_towerlist;
         std::list<FlagCacheItem*> d_flaglist;
         std::list<TempleCacheItem*> d_templelist;
         std::list<StoneCacheItem*> d_stonelist;
         std::list<RoadCacheItem*> d_roadlist;
         std::list<FogCacheItem*> d_foglist;
         std::list<BridgeCacheItem*> d_bridgelist;
+        std::list<CursorCacheItem*> d_cursorlist;
         std::list<SelectorCacheItem*> d_selectorlist;
         std::list<ShieldCacheItem*> d_shieldlist;
         std::list<ProdShieldCacheItem*> d_prodshieldlist;
         std::list<MoveBonusCacheItem*> d_movebonuslist;
         std::list<ShipCacheItem*> d_shiplist;
+        std::list<PlantedStandardCacheItem*> d_plantedstandardlist;
 
         //some private surfaces
         SDL_Surface* d_levelmask;
         SDL_Surface* d_medalsmask;
         SDL_Surface* d_citypic[MAX_PLAYERS + 1]; //+1 for neutral
+        SDL_Surface* d_towerpic[MAX_PLAYERS];
         SDL_Surface* d_templepic[TEMPLE_TYPES];
         SDL_Surface* d_stonepic[STONE_TYPES];
         SDL_Surface* d_roadpic[ROAD_TYPES];
         SDL_Surface* d_bridgepic[BRIDGE_TYPES];
+        SDL_Surface* d_cursorpic[CURSOR_TYPES];
         SDL_Surface* d_razedpic[MAX_PLAYERS + 1]; //+1 for neutral
         SDL_Surface* d_flagpic[8];
         SDL_Surface* d_flagmask[8];
@@ -390,8 +458,11 @@ class GraphicsCache
         SDL_Surface* d_movebonuspic[6];
 	SDL_Surface* d_ship;
 	SDL_Surface* d_shipmask;
+	SDL_Surface* d_planted_standard;
+	SDL_Surface* d_planted_standard_mask;
 	SDL_Surface* d_port;
 	SDL_Surface* d_small_ruin_unexplored;
+	SDL_Surface* d_small_stronghold_unexplored;
 	SDL_Surface* d_small_ruin_explored;
 	SDL_Surface* d_small_temple;
 	SDL_Surface *d_fogpic[FOG_TYPES];
