@@ -107,6 +107,8 @@ void NextTurn::startTurn()
     //a shortcut
     Player* p = Playerlist::getActiveplayer();
 
+    p->initTurn();
+
     //if turnmode is set, create/heal armies at player's turn
     if (d_turnmode)
     {
@@ -150,8 +152,11 @@ void NextTurn::finishRound()
 
             //heal armies
             (*pit)->getStacklist()->nextTurn();
+
         }
     }
+	
+    Playerlist::getInstance()->calculateWinners();
 
     // heal the stacks in the ruins
     Ruinlist* rl = Ruinlist::getInstance();
