@@ -137,7 +137,9 @@ void QuestsManager::questCompleted(Uint32 heroId)
 {
     Quest *quest = d_quests[heroId];
     Player *p = quest->getHero()->getPlayer();
-    
+
+    p->heroCompletesQuest(quest->getHero());
+
     int num = rand() % 4;
     if (num == 0)
       {
@@ -238,7 +240,10 @@ bool QuestsManager::save(XML_Helper* helper) const
     
     std::map<Uint32,Quest*>::const_iterator it;
     for (it = d_quests.begin(); it != d_quests.end(); it++) 
-        retval &= ((*it).second)->save(helper);
+      {
+	if (((*it).second)->isPendingDeletion() == false)
+	  retval &= ((*it).second)->save(helper);
+      }
 
     debug("Quests saved\n");
 	retval &= helper->closeTag();
