@@ -486,6 +486,71 @@ void BigMap::drawFogTile (int x, int y)
   return;
 }
 
+void BigMap::draw_stack(Stack *s)
+{
+  GameMap *gm = GameMap::getInstance();
+  GraphicsCache *gc = GraphicsCache::getInstance();
+  int tilesize = GameMap::getInstance()->getTileSet()->getTileSize();
+  Vector<int> p = s->getPos();
+  Player *player = s->getPlayer();
+
+  // check if the object lies in the viewed part of the map
+  // otherwise we shouldn't draw it
+  if (is_inside(buffer_view, p) && !s->getDeleting())
+    {
+      if (s->empty())
+	{
+	  std::cerr << "WARNING: empty stack found" << std::endl;
+	  return;
+	}
+
+      p = tile_to_buffer_pos(p);
+
+      // draw stack
+		
+      SDL_Rect r;
+      r.x = p.x + 6;
+      r.y = p.y + 6;
+      r.w = r.h = 54;
+
+      bool show_army = true;
+      if (s->hasShip())
+	SDL_BlitSurface(gc->getShipPic(player), 0, buffer, &r);
+      else
+	{
+	  if (s->getFortified() == true)
+	    {
+	      if (player->getStacklist()->getActivestack() != s &&
+		  player == Playerlist::getActiveplayer())
+		show_army = false;
+	      Maptile *tile = gm->getTile(s->getPos());
+	      if (tile->getBuilding() != Maptile::CITY &&
+		  tile->getBuilding() != Maptile::RUIN &&
+		  tile->getBuilding() != Maptile::TEMPLE)
+		SDL_BlitSurface(gc->getTowerPic(player), 0, buffer, &r);
+	      else
+		show_army = true;
+	    }
+		      
+	  if (show_army == true)
+	    {
+	      Army *a = *s->begin();
+	      SDL_BlitSurface(a->getPixmap(), 0, buffer, &r);
+	    }
+	}
+
+		
+      if (show_army)
+	{
+	  // draw flag
+	  r.x = p.x;
+	  r.y = p.y;
+	  r.w = r.h = tilesize;
+	  SDL_BlitSurface(gc->getFlagPic(s), 0, buffer, &r);
+	}
+    }
+}
+
 void BigMap::draw_buffer()
 {
     GraphicsCache *gc = GraphicsCache::getInstance();
@@ -530,18 +595,47 @@ void BigMap::draw_buffer()
 	 i != Citylist::getInstance()->end(); ++i)
 	blit_if_inside_buffer(*i, gc->getCityPic(&*i));
 
+    GameMap *gm = GameMap::getInstance();
     // If there are any items lying around, blit the itempic as well
     for (int x = buffer_view.x; x < buffer_view.x + buffer_view.w; x++)
         for (int y = buffer_view.y; y < buffer_view.y + buffer_view.h; y++)
 	    if (x < GameMap::getWidth() && y < GameMap::getHeight()
-		&& !GameMap::getInstance()->getTile(x,y)->getItems().empty())
+		&& !gm->getTile(x,y)->getItems().empty())
 	    {
+	        std::list<Item*> items = gm->getTile(x, y)->getItems();
+                bool standard_planted = false;
+                Item *flag = NULL;
+                for (std::list<Item*>::iterator it = items.begin(); 
+                     it != items.end(); it++)
+                {
+                     if ((*it)->getPlanted() == true)
+                     {
+                           standard_planted = true;
+                           flag = *it;
+                           break;
+                     }
+                }
+
+                //only show one of the bag or the flag
 		Vector<int> p = tile_to_buffer_pos(Vector<int>(x, y));
-		SDL_Rect r;
-		r.x = p.x+(tilesize-15);
-		r.y = p.y+(tilesize-15);
-		r.w = r.h = 10;
-		SDL_BlitSurface(d_itempic, 0, buffer,&r);
+                if (standard_planted && flag)
+                {
+		    SDL_Rect r;
+		    r.x = p.x+(tilesize-54);
+		    r.y = p.y+(tilesize-54);
+		    r.w = r.h = 54;
+                    SDL_Surface *surf;
+                    surf = gc->getPlantedStandardPic(flag->getPlantableOwner());
+		    SDL_BlitSurface(surf, 0, buffer,&r);
+                }
+                else
+                {
+		    SDL_Rect r;
+		    r.x = p.x+(tilesize-15);
+		    r.y = p.y+(tilesize-15);
+		    r.w = r.h = 10;
+		    SDL_BlitSurface(d_itempic, 0, buffer,&r);
+                }
 	    }
 
     // Draw stacks
@@ -551,57 +645,31 @@ void BigMap::draw_buffer()
         Stacklist* mylist = (*pit)->getStacklist();
         for (Stacklist::iterator it= mylist->begin(); it != mylist->end(); it++)
         {
-            Vector<int> p = (*it)->getPos();
-
-            // check if the object lies in the viewed part of the map
-            // otherwise we shouldn't draw it
-            if (is_inside(buffer_view, p) && !(*it)->getDeleting())
-            {
-		if ((*it)->empty())
-		{
-		    std::cerr << "WARNING: empty stack found" << std::endl;
-		    continue;
-		}
-
-                p = tile_to_buffer_pos(p);
-
-                // draw stack
-		SDL_Rect r;
-		r.x = p.x + 6;
-		r.y = p.y + 6;
-		r.w = r.h = 54;
-                if ((*it)->hasShip())
-                  SDL_BlitSurface(gc->getShipPic((*pit)), 0, buffer, &r);
-                else
-                  SDL_BlitSurface((*it)->getStrongestArmy()->getPixmap(), 0,
-				  buffer, &r);
-
-                // draw flag
-		r.x = p.x;
-		r.y = p.y;
-		r.w = r.h = tilesize;
-                SDL_BlitSurface(gc->getFlagPic(*it), 0, buffer, &r);
-            }
-        }
+	  if (*pit == Playerlist::getInstance()->getActiveplayer() &&
+	      *it == (*pit)->getStacklist()->getActivestack())
+	    ; //skip it.  the selected stack gets drawn in gamebigmap.
+	  else
+	    draw_stack (*it);
+	}
     }
 
     // fog it up
     for (int x = buffer_view.x; x < buffer_view.x + buffer_view.w; x++)
       {
-        for (int y = buffer_view.y; y < buffer_view.y + buffer_view.h; y++)
-          {
+	for (int y = buffer_view.y; y < buffer_view.y + buffer_view.h; y++)
+	  {
 	    if (x < GameMap::getWidth() && y < GameMap::getHeight())
-              {
-                Player *p = Playerlist::getActiveplayer();
-                Vector<int> pos;
-                pos.x = x;
-                pos.y = y;
-                if (p->getFogMap()->getFogTile(pos) == FogMap::CLOSED &&
-                    p->getFogMap()->isLoneFogTile(pos) == false)
-                  drawFogTile (x, y);
-              }
-          }
-        }
+	      {
+		Player *p = Playerlist::getActiveplayer();
+		Vector<int> pos;
+		pos.x = x;
+		pos.y = y;
+		if (p->getFogMap()->getFogTile(pos) == FogMap::CLOSED &&
+		    p->getFogMap()->isLoneFogTile(pos) == false)
+		  drawFogTile (x, y);
+	      }
+	  }
+      }
 
     after_draw();
 
