@@ -201,6 +201,116 @@ City* Citylist::getNearestCity(const Vector<int>& pos)
     return &(*diffit);
 }
 
+City* Citylist::getNearestVisibleCity(const Vector<int>& pos)
+{
+    int diff = -1;
+    iterator diffit;
+
+    for (iterator it = begin(); it != end(); ++it)
+    {
+          if ((*it).isBurnt())
+              continue;
+
+          if ((*it).isFogged() == true)
+              continue;
+          
+          Vector<int> p = (*it).getPos();
+          int delta = abs(p.x - pos.x);
+          if (delta < abs(p.y - pos.y))
+              delta = abs(p.y - pos.y);
+          
+          if ((diff > delta) || (diff == -1))
+          {
+              diff = delta;
+              diffit = it;
+          }
+    }
+    
+    if (diff == -1) return 0;
+    return &(*diffit);
+}
+
+City* Citylist::getNearestVisibleCity(const Vector<int>& pos, int dist)
+{
+  City *c = getNearestVisibleCity(pos);
+  if (c->getPos().x <= pos.x + dist && c->getPos().x >= pos.x - dist &&
+      c->getPos().y <= pos.y + dist && c->getPos().y >= pos.y - dist)
+    return c;
+  return NULL;
+}
+
+City* Citylist::getNearestVisibleFriendlyCity(const Vector<int>& pos, int dist)
+{
+  City *c = getNearestFriendlyCity(pos);
+  if (c->getPos().x <= pos.x + dist && c->getPos().x >= pos.x - dist &&
+      c->getPos().y <= pos.y + dist && c->getPos().y >= pos.y - dist)
+    return c;
+  return NULL;
+}
+
+City* Citylist::getNearestVisibleFriendlyCity(const Vector<int>& pos)
+{
+    int diff = -1;
+    iterator diffit;
+    Player* p = Playerlist::getInstance()->getActiveplayer();
+    
+    for (iterator it = begin(); it != end(); ++it)
+    {
+        if ((*it).isBurnt())
+            continue;
+
+	if ((*it).isFogged())
+	    continue;
+
+        if ((*it).getPlayer() == p)
+        {
+            Vector<int> p = (*it).getPos();
+            int delta = abs(p.x - pos.x);
+            if (delta < abs(p.y - pos.y))
+                delta = abs(p.y - pos.y);
+            
+            if ((diff > delta) || (diff == -1))
+            {
+                diff = delta;
+                diffit = it;
+            }
+        }
+    }
+    
+    if (diff == -1) return 0;
+    return &(*diffit);
+}
+
+City* Citylist::getNearestNeutralCity(const Vector<int>& pos)
+{
+    int diff = -1;
+    iterator diffit;
+    
+    for (iterator it = begin(); it != end(); ++it)
+    {
+        if ((*it).isBurnt())
+            continue;
+
+        if ((*it).getPlayer() == Playerlist::getInstance()->getNeutral())
+        {
+            Vector<int> p = (*it).getPos();
+            int delta = abs(p.x - pos.x);
+            if (delta < abs(p.y - pos.y))
+                delta = abs(p.y - pos.y);
+            
+            if ((diff > delta) || (diff == -1))
+            {
+                diff = delta;
+                diffit = it;
+            }
+        }
+    }
+    
+    if (diff == -1) return 0;
+    return &(*diffit);
+}
+
+
 City* Citylist::getFirstCity(Player* p)
 {
     for (iterator it = begin(); it != end(); it++)
