@@ -20,8 +20,8 @@
 
 #include <libintl.h>
 
-#define LORDSAWAR_SAVEGAME_VERSION "0.0.2"
-#define LORDSAWAR_CONFIG_VERSION "0.0.2"
+#define LORDSAWAR_SAVEGAME_VERSION "0.0.3"
+#define LORDSAWAR_CONFIG_VERSION "0.0.3"
 #define ENABLE_NLS 1 // Very important toactivate localization
 #define _(string) gettext(string) // Macro for the gettext
 #define __(astring) std::string(gettext(astring.c_str()))
@@ -36,10 +36,12 @@ const unsigned int TIMER_SMALLMAP_REFRESH=50;
 const unsigned int CITY_LEVELS=4; 
 const unsigned int MAX_PLAYERS=8;
 const unsigned int TEMPLE_TYPES=2; 
+const unsigned int RUIN_TYPES=2; 
 const unsigned int STONE_TYPES=9; 
 const unsigned int ROAD_TYPES=12; 
 const unsigned int FOG_TYPES=13; 
 const unsigned int BRIDGE_TYPES=2; 
+const unsigned int CURSOR_TYPES=12; 
 const unsigned int SIGNPOSTS_RATIO=6; // #:1 dynamic vs static signposts
 const unsigned int MAX_ARMIES_VECTORED_TO_ONE_CITY = 4;
 const unsigned int MAX_TURNS_FOR_VECTORING = 2;
