@@ -48,8 +48,23 @@ struct GameParameters
 	PROCESS_ARMIES_AT_PLAYERS_TURN = 0,
 	PROCESS_ARMIES_WHEN_ROUND_BEGINS
     };
-
     ProcessArmies process_armies;
+
+    bool see_opponents_stacks;
+    bool see_opponents_production;
+    bool play_with_quests;
+    bool hidden_map;
+    bool diplomacy;
+
+    enum NeutralCities {
+        AVERAGE = 0, STRONG, ACTIVE
+    };
+    NeutralCities neutral_cities;
+
+    bool quick_start;
+    bool intense_combat;
+    bool military_advisor;
+    bool random_turns;
 };
 
 #endif
