@@ -58,11 +58,10 @@ class Game
 
     void redraw();
 
-    void select_prev_stack();
-    void select_next_stack();
     void select_next_movable_stack();
     void center_selected_stack();
     void defend_selected_stack();
+    void park_selected_stack();
     void search_selected_stack();
     void move_selected_stack();
     void move_all_stacks();
@@ -82,17 +81,19 @@ class Game
     sigc::signal<void, SDL_Surface *> smallmap_changed;
     sigc::signal<void, SidebarStats> sidebar_stats_changed;
     sigc::signal<void, bool>
-	can_select_prev_stack,
-	can_select_next_stack,
 	can_select_next_movable_stack,
 	can_center_selected_stack,
 	can_defend_selected_stack,
+	can_park_selected_stack,
 	can_search_selected_stack,
 	can_inspect_selected_stack,
+	can_plant_standard_selected_stack,
 	can_move_selected_stack,
+	can_group_ungroup_selected_stack,
 	can_move_all_stacks,
 	can_disband_stack,
 	can_change_signpost,
+	can_see_history,
 	can_end_turn;
     sigc::signal<void, Stack *> stack_info_changed;
     sigc::signal<void, Glib::ustring, MapTipPosition> map_tip_changed;
@@ -102,13 +103,15 @@ class Game
     sigc::signal<void, Stack *, Stack *> ruinfight_started;
     sigc::signal<void, Fight::Result> ruinfight_finished;
     sigc::signal<bool, Player *, Hero *, City *, int> hero_offers_service;
-    sigc::signal<bool, bool, Temple *, int> temple_visited;
+    sigc::signal<bool, bool, Temple *, int> temple_searched;
     sigc::signal<void, Hero *, Quest *> quest_assigned;
     sigc::signal<CityDefeatedAction, City *, int> city_defeated;
     sigc::signal<void, City *, int, unsigned int> city_pillaged;
     sigc::signal<void, City *, int, std::list<Uint32> > city_sacked;
     sigc::signal<void, City *> city_razed;
     sigc::signal<void, City *> city_visited;
+    sigc::signal<void, Ruin *> ruin_visited;
+    sigc::signal<void, Temple *> temple_visited;
     sigc::signal<void, Player *, unsigned int> next_player_turn;
     sigc::signal<void, int> hero_arrives;
     sigc::signal<void, Army *> medal_awarded_to_army;
@@ -144,8 +147,8 @@ class Game
     // bigmap callbacks
     void on_stack_selected(Stack* s);
     void on_city_queried (City* c, bool brief);
-    void on_ruin_queried (Ruin* r);
-    void on_temple_queried (Temple* t);
+    void on_ruin_queried (Ruin* r, bool brief);
+    void on_temple_queried (Temple* t, bool brief);
     void on_signpost_queried (Signpost* s);
     void on_stack_queried (Stack* s);
 
