@@ -21,6 +21,7 @@
 
 #include "vector.h"
 #include "input-events.h"
+#include "GraphicsCache.h"
 #include "bigmap.h"
 
 class Stack;
@@ -50,13 +51,15 @@ class GameBigMap: public BigMap
     // signals for mouse clicks, deselect is signified with a null pointer
     sigc::signal<void, Stack*> stack_selected;
     sigc::signal<void, City*, bool> city_queried; // true => show brief info
-    sigc::signal<void, Ruin*> ruin_queried;
+    sigc::signal<void, Ruin*, bool> ruin_queried; //true => show brief info
     sigc::signal<void, Signpost*> signpost_queried;
     sigc::signal<void, Stack*> stack_queried;
-    sigc::signal<void, Temple*> temple_queried;
+    sigc::signal<void, Temple*, bool> temple_queried; //true=>show brief info
 
     // emitted when a path for a stack is set
     sigc::signal<void> path_set;
+    // emitted when the cursor changes
+    sigc::signal<void, GraphicsCache::CursorType> cursor_changed;
 
  private:
     SDL_Surface* d_arrows;
@@ -69,6 +72,7 @@ class GameBigMap: public BigMap
 	SHOWING_TEMPLE, SHOWING_SIGNPOST, SHOWING_STACK
     } mouse_state;
 	
+    GraphicsCache::CursorType d_cursor;
 
     // for the marching ants around selected stack
     sigc::connection selection_timeout_handler;
