@@ -274,13 +274,13 @@ void CityWindow::fill_in_production_info()
 	s2 += "\n";
 	s2 += String::ucompose(_("Cost: %1"), a->getUpkeep());
 
-        s3 = String::ucompose(_("%1t"), a->getProduction() - 
-                              city->getDuration() + 1);
+        s3 = String::ucompose(_("%1t"), city->getDuration());
         if (city->getVectoring() != Vector<int>(-1, -1))
           {
             Citylist *cl = Citylist::getInstance();
             City *dest = cl->getObjectAt(city->getVectoring());
-            s3 += String::ucompose(_(", then to %1"), dest->getName());
+            s3 += String::ucompose(_(", then to %1"), 
+                                   dest ? dest->getName() : "Standard");
           }
       pic = to_pixbuf(gc->getArmyPic(as, a->getType(), player, 1, NULL));
     }
@@ -375,12 +375,15 @@ void CityWindow::on_buy_clicked()
     if (army != BuyProductionDialog::NO_ARMY_SELECTED)
     {
 	int slot = -1;
-	for (unsigned int i = 0; i < production_toggles.size(); ++i)
-	    if (production_toggles[i]->get_active()) {
-		slot = i;
-		break;
-	    }
+	slot = city->getFreeBasicSlot();
 	
+	if  (slot == -1)
+	  {
+	    //no free slots available.  change the one we're on.
+	    slot = city->getProductionIndex();
+	    if (slot == -1) 
+	      slot = 0;
+	  }
 	city->getPlayer()->cityBuyProduction(city, slot, army);
 	city->getPlayer()->cityChangeProduction(city, slot);
 
