@@ -27,6 +27,7 @@
 #include "../player.h"
 #include "../army.h"
 #include "../armysetlist.h"
+#include "../GraphicsCache.h"
 
 FightOrderDialog::FightOrderDialog(Player *theplayer)
 {
@@ -87,10 +88,13 @@ void FightOrderDialog::run()
 
 void FightOrderDialog::addArmyType(Uint32 army_type)
 {
+    GraphicsCache *gc = GraphicsCache::getInstance();
     Gtk::TreeIter i = armies_list->append();
     Armysetlist *alist = Armysetlist::getInstance();
     const Army *a = alist->getArmy(player->getArmyset(), army_type);
     (*i)[armies_columns.name] = a->getName();
-    (*i)[armies_columns.image] = to_pixbuf(a->getPixmap());
+    (*i)[armies_columns.image] = to_pixbuf(gc->getArmyPic(player->getArmyset(),
+                                           army_type,
+                                           player, 1, NULL));
     (*i)[armies_columns.army_type] = a->getType();
 }
