@@ -166,7 +166,7 @@ GamePreferencesDialog::GamePreferencesDialog()
 
     Gtk::FileFilter map_filter;
     map_filter.add_pattern("*.map");
-    //map_filter.set_name(_("Maps (*.map)"));
+    map_filter.set_name(_("LordsAWar map files (*.map)"));
     load_map_filechooser->set_filter(map_filter);
 
     xml->connect_clicked(
@@ -261,9 +261,9 @@ void GamePreferencesDialog::on_map_size_changed()
 
     case MAP_SIZE_NORMAL:
     default:
-	cities_scale->set_value(20);
+	cities_scale->set_value(40);
 	ruins_scale->set_value(25);
-	temples_scale->set_value(25);
+	temples_scale->set_value(10);
 	break;
     }
 }
