@@ -21,6 +21,7 @@
 #include <sigc++/trackable.h>
 #include <gtkmm/window.h>
 #include <gtkmm/dialog.h>
+#include <gtkmm/eventbox.h>
 #include <gtkmm/container.h>
 #include <gtkmm/image.h>
 #include <gtkmm/button.h>
@@ -40,6 +41,7 @@
 #include "../callback-enums.h"
 #include "../vector.h"
 #include "../army.h"
+#include "../GraphicsCache.h"
 
 class Game;
 class SDL_Surface;
@@ -98,6 +100,14 @@ class GameWindow: public sigc::trackable
     Gtk::MenuItem *inspect_menuitem;
     Gtk::MenuItem *disband_menuitem;
     Gtk::MenuItem *signpost_menuitem;
+    Gtk::MenuItem *city_history_menuitem;
+    Gtk::MenuItem *event_history_menuitem;
+    Gtk::MenuItem *gold_history_menuitem;
+    Gtk::MenuItem *winner_history_menuitem;
+    Gtk::MenuItem *plant_standard_menuitem;
+    Gtk::MenuItem *group_ungroup_menuitem;
+    Gtk::MenuItem *leave_menuitem;
+    Gtk::MenuItem *next_menuitem;
     Gtk::Box *stack_info_box;
     Gtk::Box *stack_info_container;
     Gtk::Label *group_moves_label;
@@ -115,11 +125,10 @@ class GameWindow: public sigc::trackable
     Gtk::Image *shield_image[MAX_PLAYERS];
     
     // the button control panel
-    Gtk::Button *prev_button;
-    Gtk::Button *next_button;
     Gtk::Button *next_movable_button;
     Gtk::Button *center_button;
     Gtk::Button *defend_button;
+    Gtk::Button *park_button;
     Gtk::Button *search_button;
     Gtk::Button *move_button;
     Gtk::Button *move_all_button;
@@ -130,6 +139,8 @@ class GameWindow: public sigc::trackable
     std::auto_ptr<StackInfoTip> stack_info_tip;
     typedef std::vector<Gtk::ToggleButton *> army_buttons_type;
     army_buttons_type army_buttons;
+    Gtk::EventBox *map_eventbox;
+    Gtk::ToggleButton *group_ungroup_toggle;
 
     std::string current_save_filename;
 
@@ -149,35 +160,46 @@ class GameWindow: public sigc::trackable
     void on_load_game_activated();
     void on_save_game_activated();
     void on_save_game_as_activated();
-    void on_resign_game_activated();
     void on_quit_activated();
-    void on_armies_activated();
-    void on_cities_activated();
-    void on_gold_activated();
     void on_quests_activated();
     void on_disband_activated();
     void on_resign_activated();
     void on_signpost_activated();
     void on_inspect_activated();
+    void on_plant_standard_activated();
+    void on_item_bonus_activated();
+    void on_army_report_activated();
+    void on_city_report_activated();
+    void on_gold_report_activated();
+    void on_production_report_activated();
+    void on_winning_report_activated();
 
     void on_fullscreen_activated();
     void on_preferences_activated();
+    void on_group_ungroup_activated();
     
     void on_fight_order_activated();
+    void on_levels_activated();
+    void on_ruin_report_activated();
+    void on_army_bonus_activated();
+    void on_city_history_activated();
+    void on_event_history_activated();
+    void on_gold_history_activated();
+    void on_winner_history_activated();
 
     void on_message_requested(std::string msg);
-    void on_stack_selected_in_report(Stack *stack);
-    void on_city_selected_in_report(City *city);
     
     // info pane at the bottom
     void show_stats();
     void show_stack(Stack *s);
     void fill_in_group_info (Stack *s);
     void on_army_toggled(Gtk::ToggleButton *toggle, Army *army);
+    void on_group_toggled(Gtk::ToggleButton *toggle);
     bool on_army_button_event(GdkEventButton *e,
 			      Gtk::ToggleButton *toggle, Army *army);
     void on_army_button_has_size();
     void clear_army_buttons();
+    void update_army_buttons();
     void ensure_one_army_button_active();
 
     // shield set on the top
@@ -186,6 +208,7 @@ class GameWindow: public sigc::trackable
     // game callbacks
     void on_sidebar_stats_changed(SidebarStats s);
     void on_smallmap_changed(SDL_Surface *map);
+    void on_bigmap_cursor_changed(GraphicsCache::CursorType cursor);
     void on_stack_info_changed(Stack *s);
     void on_map_tip_changed(Glib::ustring tip, MapTipPosition pos);
     void on_stack_tip_changed(Stack *s, MapTipPosition pos);
@@ -195,13 +218,15 @@ class GameWindow: public sigc::trackable
     void on_ruinfight_started(Stack *attackers, Stack *defenders);
     void on_ruinfight_finished(Fight::Result result);
     bool on_hero_offers_service(Player *player, Hero *hero, City *city, int gold);
-    bool on_temple_visited(bool hasHero, Temple *temple, int blessCount);
+    bool on_temple_searched(bool hasHero, Temple *temple, int blessCount);
     void on_quest_assigned(Hero *hero, Quest *quest);
     CityDefeatedAction on_city_defeated(City *city, int gold);
     void on_city_pillaged(City *city, int gold, int pillaged_army_type);
     void on_city_sacked(City *city, int gold, std::list<Uint32> sacked_types);
     void on_city_razed(City *city);
     void on_city_visited(City *city);
+    void on_ruin_visited(Ruin *ruin);
+    void on_temple_visited(Temple *temple);
     void on_next_player_turn(Player *player, unsigned int turn_number);
     void on_hero_brings_allies(int alliesCount);
     void on_medal_awarded_to_army(Army *army);
@@ -220,11 +245,16 @@ class GameWindow: public sigc::trackable
     void hide_map_tip();
 
     void setup_game(std::string file_path);
+    void setup_signals();
     void stop_game();
+    std::list<sigc::connection> connections;
     
+    void setup_menuitem(Gtk::MenuItem*, sigc::slot<void> , sigc::signal<void, bool> &);
+    void setup_button(Gtk::Button *, sigc::slot<void> slot, sigc::signal<void, bool> &);
 public:
     // not part of the API, but for surface_attached_helper
     void on_sdl_surface_changed();
+    bool d_quick_fights; //do we speed up fights for this player's turn?
 };
 
 #endif
