@@ -263,46 +263,8 @@ void OverviewMap::draw_terrain_pixels(Rectangle r)
     
 }
 
-void OverviewMap::draw_stacks()
-{
-    assert(surface);
-    
-    // minimum size for typical features is 1
-    int size = int(pixels_per_tile) > 1 ? int(pixels_per_tile) : 1;
-
-
-    // Draw stacks as crosses using the player color
-    for (Playerlist::iterator pit = Playerlist::getInstance()->begin();
-        pit != Playerlist::getInstance()->end(); pit++)
-    {
-        Stacklist* mylist = (*pit)->getStacklist();
-        SDL_Color c = (*pit)->getColor();
-	Uint32 outline = SDL_MapRGB(surface->format, c.r, c.g, c.b);
-        
-        for (Stacklist::iterator it= mylist->begin(); it != mylist->end(); it++)
-        {
-            Vector<int> pos = (*it)->getPos();
-
-            // don't draw stacks in cities, they could hardly be identified
-            Maptile* mytile = GameMap::getInstance()->getTile(pos.x, pos.y);
-            if (mytile->getBuilding() == Maptile::CITY)
-                continue;
-
-            // don't draw stacks on tiles we can't see
-            if (isFogged (pos) == true)
-                continue;
-
-            pos = mapToSurface(pos);
-            draw_hline(surface, pos.x - size, pos.x + size, pos.y, outline);
-            draw_vline(surface, pos.x, pos.y - size, pos.y + size, outline);
-        }
-    }
-}
-
 void OverviewMap::after_draw()
 {
-    assert(surface);
-    draw_stacks();
 }
 
 void OverviewMap::draw()
@@ -320,7 +282,7 @@ void OverviewMap::draw()
     
     SDL_BlitSurface(static_surface, 0, surface, 0);
 
-    // Draw ruins as yellow boxes
+    // Draw ruins as a white dot
     for (Ruinlist::iterator it = Ruinlist::getInstance()->begin();
         it != Ruinlist::getInstance()->end(); it++)
     {
