@@ -32,6 +32,7 @@ class Stacklist;
 class XML_Helper;
 class Hero;
 class Action;
+class History;
 class City;
 class Quest;
 class Army;
@@ -179,6 +180,9 @@ class Player: public sigc::trackable
         //! Remove all items from the list of player's actions
         void clearActionlist();
 
+        //! Remove all items from the list of player's events
+        void clearHistorylist();
+
         //! Add a stack to the player's list of stacks
         void addStack(Stack* stack);
 
@@ -192,6 +196,9 @@ class Player: public sigc::trackable
         //! Returns the list of player's actions. 
         std::list<Action*>* getActionlist() {return &d_actions;}
 
+        //! Returns the list of player's events. 
+        std::list<History*>* getHistorylist() {return &d_history;}
+
         //! Return the player's armyset
         Uint32 getArmyset() const {return d_armyset;}
 
@@ -234,6 +241,9 @@ class Player: public sigc::trackable
         //! Dumps the items in the actionlist on stderr
         void dumpActionlist() const;
 
+        //! Dumps the items in the eventlist on stderr
+        void dumpHistorylist() const;
+
         //! Mark the player as dead; this kills all his armies etc.
         void kill();
 
@@ -263,10 +273,17 @@ class Player: public sigc::trackable
         /** This function is called when a player's turn starts. For AI players,
           * this function should start the algorithm.
           *
-          * @return true if wverything went well
+          * @return true if everything went well
           */
         virtual bool startTurn() = 0;
 
+        /** This function is called before a player's turn starts.
+          * The idea here is that it happens before heroes are recruited,
+          * and before new army units show up in cities
+          * @return true if everything went well
+          */
+        virtual bool initTurn() = 0;
+
         /** Called so that the player can decide what to do with an
             occupied city as soon as he has occupied it (mainly for AI)
 
@@ -437,6 +454,18 @@ class Player: public sigc::trackable
         //! Disband a player's stack
         virtual bool stackDisband(Stack* s) =0;
 
+        //! Player's hero drop an item at pos
+        virtual bool heroDropItem(Hero *h, Item *item, Vector<int> pos) =0;
+
+        //! Player's hero drops all items at pos
+        virtual bool heroDropAllItems(Hero *h, Vector<int> pos) =0;
+
+        //! Player's hero picks up an item
+        virtual bool heroPickupItem(Hero *h, Item *item, Vector<int> pos) =0;
+
+        //! Player's hero completes a quest
+        virtual bool heroCompletesQuest(Hero *h) =0;
+
         //! Disband all the player's stacks and raze all cities.
         virtual void resign() =0;
 
@@ -453,6 +482,12 @@ class Player: public sigc::trackable
           */
         virtual bool vectorFromCity(City* c, Vector<int> dest) = 0;
 
+        //! Plant a standard
+        virtual bool heroPlantStandard(Stack *s) =0;
+
+	//! return the player's current score
+        virtual Uint32 getScore() =0;
+
         /** Signal raised when a city is conquered. This signal is solely
           * for internal use. Don't use it, you may break stability (Background:
           * libsigc++ doesn't guarantee order of execution and this signal may
@@ -518,6 +553,7 @@ class Player: public sigc::trackable
         Uint32 d_type;
         Uint32 d_id;
         std::list<Action*> d_actions; //list of actions done by the player
+        std::list<History*> d_history; //player's history
         Stacklist* d_stacklist;
         FogMap* d_fogmap;
 	std::list<Uint32> d_fight_order; //for each army in armyset, a number
