@@ -23,6 +23,9 @@
 //#include "FightDialog.h"
 #include "stacklist.h"
 #include "citylist.h"
+#include "templelist.h"
+#include "ruinlist.h"
+#include "signpostlist.h"
 #include "rewardlist.h"
 #include "QuestsManager.h"
 #include "path.h"
@@ -38,6 +41,7 @@
 #include "GameScenario.h"
 #include "game-parameters.h"
 #include "signpost.h"
+#include "history.h"
 
 using namespace std;
 
@@ -77,10 +81,16 @@ bool RealPlayer::save(XML_Helper* helper) const
     return retval;
 }
 
-bool RealPlayer::startTurn()
+bool RealPlayer::initTurn()
 {
     clearActionlist();
+    History_StartTurn* item = new History_StartTurn();
+    d_history.push_back(item);
+    return true;
+}
 
+bool RealPlayer::startTurn()
+{
     return true;
 }
 
@@ -98,6 +108,10 @@ bool RealPlayer::recruitHero(Hero* hero, City *city, int cost)
     // for the realplayer, this function also just raises a signal and looks
     // what to do next.
 
+    History_HeroEmerges *item = new History_HeroEmerges();
+    item->fillData(hero, city);
+    d_history.push_back(item);
+
     return srecruitingHero.emit(hero, city, cost);
 }
 
@@ -191,8 +205,8 @@ bool RealPlayer::stackJoin(Stack* receiver, Stack* joining, bool grouped)
 
     joining->clear();    //clear only erases the pointers not the armies
     d_stacklist->flRemove(joining);
-    supdatingStack.emit(0);
 
+    d_stacklist->setActivestack(receiver);
     return true;
 }
 
@@ -293,6 +307,8 @@ MoveResult *RealPlayer::stackMove(Stack* s, Vector<int> dest, bool follow)
         {
             Fight::Result result;
             MoveResult *moveResult = new MoveResult(true);
+	    if (stackMoveOneStep(s))
+	      stepCount++;
             vector<Stack*> def_in_city = Stacklist::defendersInCity(city);
             if (!def_in_city.empty())
             {
@@ -311,18 +327,24 @@ MoveResult *RealPlayer::stackMove(Stack* s, Vector<int> dest, bool follow)
             moveResult->setFightResult(result);
 
             // We may only take the city if we have defeated all defenders
-            if (Stacklist::defendersInCity(city).empty())
+            if (result == Fight::ATTACKER_WON)
             {
-                if (stackMoveOneStep(s))
-                    stepCount++;
                 invadeCity(city); //determine what to do with city
+
+                History_CityWon *item = new History_CityWon();
+                item->fillData(city);
+                d_history.push_back(item);
+		if (s->hasHero())
+		  {
+		    History_HeroCityWon *another = new History_HeroCityWon();
+		    Hero *hero = dynamic_cast<Hero *>(s->getFirstHero());
+		    another->fillData(hero, city);
+		    d_history.push_back(another);
+		  }
             }
-            else if (s)
+            else
             {
-                // we didn't suceed in defeating the defenders, but at least our
-                // stack has survived. Subtract some MP because fighting takes
-                // time.
-                s->decrementMoves(2);
+                // we didn't suceed in defeating the defenders
                 //if this is a neutral city, and we're playing with 
                 //active neutral cities, AND it hasn't already been attacked
                 //then it's production gets turned on
@@ -479,8 +501,6 @@ Fight::Result ruinfight (Stack **attacker, Stack **defender)
       loser->getFirstHero()->setHP(0); /* only the hero dies */
     }
         
-  /* set the hp to == 0 on dead armies */
-
   return result;
 }
 
@@ -803,6 +823,41 @@ double RealPlayer::removeDeadArmies(std::list<Stack*>& stacks,
             {
                 debug("Army: " << (*sit)->getName())
                 debug("Army: " << (*sit)->getXpReward())
+                if ((*sit)->isHero())
+                {
+                    //one of our heroes died
+                    //drop hero's stuff
+                    Hero *h = static_cast<Hero *>(*sit);
+                    //now record the details of the death
+                    GameMap *gm = GameMap::getInstance();
+                    Maptile *tile = gm->getTile((*it)->getPos());
+                    if (tile->getBuilding() == Maptile::RUIN)
+                    {
+                        History_HeroKilledSearching* item;
+                        item = new History_HeroKilledSearching();
+                        item->fillData(h);
+                        h->getPlayer()->getHistorylist()->push_back(item);
+                        heroDropAllItems (h, (*it)->getPos());
+                    }
+                    else if (tile->getBuilding() == Maptile::CITY)
+                    {
+		        Citylist *clist = Citylist::getInstance();
+                        City* c = clist->getObjectAt((*it)->getPos());
+                        History_HeroKilledInCity* item;
+                        item = new History_HeroKilledInCity();
+                        item->fillData(h, c);
+                        h->getPlayer()->getHistorylist()->push_back(item);
+                        heroDropAllItems (h, (*it)->getPos());
+                    }
+                    else //somewhere else
+                    {
+                        History_HeroKilledInBattle* item;
+                        item = new History_HeroKilledInBattle();
+                        item->fillData(h);
+                        h->getPlayer()->getHistorylist()->push_back(item);
+                        heroDropAllItems (h, (*it)->getPos());
+                    }
+                }
                 //Add the XP bonus to the total of the battle;
                 total+=(*sit)->getXpReward();
                 // here we destroy the army, so we send
@@ -844,7 +899,7 @@ double RealPlayer::removeDeadArmies(std::list<Stack*>& stacks,
 
 Reward* RealPlayer::stackSearchRuin(Stack* s, Ruin* r)
 {
-    Reward *retReward;
+    Reward *retReward = NULL;
     debug("RealPlayer::stack_search_ruin")
 
     //throw out impossible actions
@@ -880,8 +935,18 @@ Reward* RealPlayer::stackSearchRuin(Stack* s, Ruin* r)
         r->setOccupant(0);
         if (keeper)
           delete keeper;
-        // The fight has been done or left out, now comes the reward. Up to now,
-        int num = rand() % 3;
+      }
+
+     if (r->hasSage())
+      {
+        History_FoundSage* history = new History_FoundSage();
+        history->fillData(dynamic_cast<Hero *>(s->getFirstHero()));
+        d_history.push_back(history);
+      }
+     else
+      {
+       // The fight has been done or left out, now comes the reward. Up to now,
+       int num = rand() % 3;
         if (num == 0)
           {
             int gold = rand() % 1000;
@@ -936,12 +1001,8 @@ Reward* RealPlayer::stackSearchRuin(Stack* s, Ruin* r)
           }
 */
       }
-   else if (r->hasSage())
-      {
-        //what do i do here?
-      }
 
-    ssearchingRuin.emit(r, s, retReward);
+    ssearchingRuin.emit(r, s, retReward); //nobody's listening for this
 
     r->setSearched(true);
 
@@ -1008,10 +1069,14 @@ Quest* RealPlayer::stackGetQuest(Stack* s, Temple* t)
         return 0;
 
     // Now fill the action item
-    Action_Quest* item = new Action_Quest();
-    item->fillData(q);
-    d_actions.push_back(item);
+    Action_Quest* action = new Action_Quest();
+    action->fillData(q);
+    d_actions.push_back(action);
 
+    // and record it for posterity
+    History_HeroQuestStarted * history = new History_HeroQuestStarted();
+    history->fillData(dynamic_cast<Hero *>(s->getFirstHero()));
+    d_history.push_back(history);
     return q;
 }
 
@@ -1067,6 +1132,11 @@ bool RealPlayer::cityPillage(City* c, int& gold, int& pillaged_army_type)
             const Army *a = c->getArmy(i);
             if (a != NULL)
               {
+		if (a->getProductionCost() == 0)
+		  {
+                    slot = i;
+		    break;
+		  }
                 if (a->getProductionCost() > max_cost)
                   {
                     max_cost = a->getProductionCost();
@@ -1078,11 +1148,11 @@ bool RealPlayer::cityPillage(City* c, int& gold, int& pillaged_army_type)
           {
             const Army *a = c->getArmy(slot);
             pillaged_army_type = a->getType();
-            gold += a->getProductionCost() / 2;
+	    if (a->getProductionCost() == 0)
+	      gold += 1500;
+	    else
+	      gold += a->getProductionCost() / 2;
             c->removeBasicProd(slot);
-            // FIXME: if we have ghosts being produced in a city,
-            // they will be pillaged last.  this is bad because
-            // they're strong and should be pillaged earler.
           }
       }
 
@@ -1124,7 +1194,10 @@ bool RealPlayer::citySack(City* c, int& gold, std::list<Uint32> *sacked_types)
             if (a != NULL)
               {
                 sacked_types->push_back(a->getType());
-                gold += a->getProductionCost() / 2;
+		if (a->getProductionCost() == 0)
+		  gold += 1500;
+		else
+		  gold += a->getProductionCost() / 2;
                 c->removeBasicProd(i);
                 max--;
               }
@@ -1142,9 +1215,14 @@ bool RealPlayer::cityRaze(City* c)
 {
     debug("RealPlayer::cityRaze")
 
-    Action_Raze* item = new Action_Raze();
-    item->fillData(c);
-    d_actions.push_back(item);
+    Action_Raze* action = new Action_Raze();
+    action->fillData(c);
+    d_actions.push_back(action);
+
+    //ugh, put a similar history event to the action on the history list
+    History_CityRazed* history = new History_CityRazed();
+    history->fillData(c);
+    d_history.push_back(history);
 
     c->setBurnt(true);
 
@@ -1342,15 +1420,104 @@ void RealPlayer::resign()
   for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
     {
       if ((*it).getPlayer() == this)
-        (*it).setBurnt(true);
+	{
+	  (*it).setBurnt(true);
+	  History_CityRazed* history = new History_CityRazed();
+	  history->fillData(&(*it));
+	  d_history.push_back(history);
+	}
     }
 
   Action_Resign* item = new Action_Resign();
   item->fillData();
   d_actions.push_back(item);
     
+  withdrawGold(getGold()); //empty the coffers!
+
   getStacklist()->setActivestack(0);
   supdatingStack.emit(0);
 }
 
+bool RealPlayer::heroPlantStandard(Stack* s)
+{
+    debug("player::heroPlantStandard(Stack*)")
+    if (!s)
+      s = getActivestack();
+    for (Stack::iterator it = s->begin(); it != s->end(); it++)
+      {
+        if ((*it)->isHero())
+	  {
+	    Hero *hero = dynamic_cast<Hero*>((*it));
+            std::list<Item*> backpack = hero->getBackpack();
+            for (std::list<Item*>::iterator i = backpack.begin(), 
+	         end = backpack.end(); i != end; ++i)
+	      {
+		if ((*i)->isPlantable() && (*i)->getPlantableOwner() == this)
+		  {
+		    //drop the item, and plant it
+		    (*i)->setPlanted(true);
+                    GameMap *gm = GameMap::getInstance();
+	            gm->getTile(s->getPos())->addItem(*i);
+	            hero->removeFromBackpack(*i);
+                    Action_Plant * item = new Action_Plant();
+                    item->fillData(hero->getId(), (*i)->getId());
+                    d_actions.push_back(item);
+                    break;
+		  }
+	      }
+	  }
+      }
+    return true;
+}
+
+bool RealPlayer::heroDropAllItems(Hero *h, Vector<int> pos)
+{
+  std::list<Item*> backpack = h->getBackpack();
+  for (std::list<Item*>::iterator i = backpack.begin(), end = backpack.end();
+    i != end; ++i)
+    heroDropItem(h, *i, pos);
+  return true;
+}
+
+bool RealPlayer::heroDropItem(Hero *h, Item *i, Vector<int> pos)
+{
+  GameMap::getInstance()->getTile(pos)->addItem(i);
+  h->removeFromBackpack(i);
+  Action_Equip* item = new Action_Equip();
+  item->fillData(h->getId(), i->getId(), Action_Equip::BACKPACK);
+  d_actions.push_back(item);
+  return true;
+}
+
+bool RealPlayer::heroPickupItem(Hero *h, Item *i, Vector<int> pos)
+{
+  GameMap::getInstance()->getTile(pos)->removeItem(i);
+  h->addToBackpack(i, 0);
+  Action_Equip* item = new Action_Equip();
+  item->fillData(h->getId(), i->getId(), Action_Equip::GROUND);
+  d_actions.push_back(item);
+  return true;
+}
+
+bool RealPlayer::heroCompletesQuest(Hero *h)
+{
+    // record it for posterity
+    History_HeroQuestCompleted* item = new History_HeroQuestCompleted();
+    item->fillData(h);
+    d_history.push_back(item);
+    return true;
+}
+
+Uint32 RealPlayer::getScore()
+{
+  //go get our last published score in the history
+  Uint32 score = 0;
+  std::list<History*>::iterator it = d_history.begin();
+  for (; it != d_history.end(); it++)
+    {
+      if ((*it)->getType() == History::SCORE)
+	score = static_cast<History_Score*>(*it)->getScore();
+    }
+  return score;
+}
 // End of file
