@@ -46,6 +46,7 @@ class RealPlayer : public Player
         
         //! Actions, see player.h for explanation
         virtual bool startTurn();
+        virtual bool initTurn();
         virtual bool invadeCity(City* c);
         virtual bool recruitHero(Hero* hero, City *city, int cost);
         virtual bool levelArmy(Army* a);
@@ -58,6 +59,12 @@ class RealPlayer : public Player
         bool vectorFromCity(City* c, Vector<int> dest);
 	void setFightOrder(std::list<Uint32> order);
         void resign();
+        bool heroPlantStandard(Stack *s);
+        bool heroDropItem(Hero *h, Item *item, Vector<int> pos);
+        bool heroDropAllItems(Hero *h, Vector<int> pos);
+        bool heroPickupItem(Hero *h, Item *item, Vector<int> pos);
+        bool heroCompletesQuest(Hero *h);
+
 
         bool stackMove(Stack* s);
         MoveResult *stackMove(Stack* s, Vector<int> dest, bool follow);
@@ -75,6 +82,7 @@ class RealPlayer : public Player
         bool cityRaze(City* c);
         bool cityBuyProduction(City* c, int slot, int type);
         bool cityChangeProduction(City* c, int slot);
+        Uint32 getScore();
 
     protected:
         /**
