@@ -114,10 +114,11 @@ vector<Stack*> Stacklist::defendersInCity(City *city)
     {
         for (int j = pos.y; j < pos.y + 2; j++)
         {
-            Stack* stack = getObjectAt(i, j);
+	    Stack *stack;
+	    stack = city->getPlayer()->getStacklist()->getOwnObjectAt(i, j);
             if (stack)
             {
-                stackvector.push_back(stack);
+	      stackvector.push_back(stack);
             }
         }
     }
@@ -138,6 +139,16 @@ unsigned int Stacklist::getNoOfStacks()
     return mysize;
 }
 
+unsigned int Stacklist::countArmies()
+{
+    unsigned int mysize = 0;
+
+    for (iterator it = begin(); it != end(); it++)
+      mysize += (*it)->size();
+
+    return mysize;
+}
+
 Stacklist::Stacklist()
     :d_activestack(0)
 {
@@ -164,89 +175,6 @@ Stacklist::~Stacklist()
 {
 }
 
-Stack* Stacklist::setPrev()
-{
-    debug("setPrev()");
-
-    reverse_iterator it = rbegin();
-
-    //first, if we already have an active stack, loop through until we meet it
-    if (d_activestack)
-    {
-        for (; (*it) != d_activestack; it++);
-        it++;   //we want to start with the previous stack :)
-    }
-
-    //continue looping until we meet the previous not defending stack of this player
-    for (; it != rend(); it++)
-        if (((*it)->getPlayer() == Playerlist::getInstance()->getActiveplayer())
-            && (!(*it)->getDefending()))
-        {
-            d_activestack = (*it);
-            return d_activestack;
-        }
-    //still not found a stack? Then start looping from the beginning until we
-    //meet the activestack again. If there is no activestack, we have already
-    //looped through the whole list, so stop here
-    if (!d_activestack)
-        return 0;
-
-    for (it = rbegin(); (*it) != d_activestack; it++)
-    {
-        if (((*it)->getPlayer() == Playerlist::getInstance()->getActiveplayer())
-            && (!(*it)->getDefending()))
-        {
-            d_activestack = (*it);
-            return d_activestack;
-        }
-    }
-
-    //still there? well, then we have only one non-defending stack left.
-    return d_activestack;
-}
-
-Stack* Stacklist::setNext()
-{
-    debug("setNext()");
-
-    iterator it = begin();
-
-    //first, if we already have an active stack, loop through until we meet it
-    if (d_activestack)
-    {
-        for (; (*it) != d_activestack; it++);
-        it++;   //we want to start with the next stack :)
-    }
-
-    //continue looping until we meet the next not defending stack of this player
-    for (; it != end(); it++)
-        if (((*it)->getPlayer() == Playerlist::getInstance()->getActiveplayer())
-            && (!(*it)->getDefending()))
-        {
-            d_activestack = (*it);
-            return d_activestack;
-        }
-
-    //still not found a stack? Then start looping from the beginning until we
-    //meet the activestack again. If there is no activestack, we have already
-    //looped through the whole list, so stop here
-    if (!d_activestack)
-        return 0;
-
-    for (it = begin(); (*it) != d_activestack; it++)
-    {
-        if (((*it)->getPlayer() == Playerlist::getInstance()->getActiveplayer())
-            && (!(*it)->getDefending()))
-        {
-            d_activestack = (*it);
-            return d_activestack;
-        }
-    }
-
-    //still there? well, then we have only one non-defending stack left.
-    return d_activestack;
-}
-
 Stack* Stacklist::getNextMovable()
 {
     Player *player = Playerlist::getInstance()->getActiveplayer();
@@ -264,7 +192,8 @@ Stack* Stacklist::getNextMovable()
     for (; it != end(); ++it)
     {
 	Stack *s = *it;
-        if (s->getPlayer() == player && !s->getDefending() && s->canMove())
+        if (s->getPlayer() == player && !s->getDefending() && 
+	    !s->getParked() && s->canMove())
 	    return s;
     }
     
@@ -277,12 +206,13 @@ Stack* Stacklist::getNextMovable()
     for (it = begin(); *it != d_activestack; ++it)
     {
 	Stack *s = *it;
-        if (s->getPlayer() == player && !s->getDefending() && s->canMove())
+        if (s->getPlayer() == player && !s->getDefending() &&
+	    !s->getParked() && s->canMove())
 	    return s;
     }
 
     //still there? well, then we have only one stack left.
-    if (d_activestack->getDefending())
+    if (d_activestack->getDefending() || d_activestack->getParked())
 	return 0;
     else
 	return d_activestack;
@@ -383,4 +313,12 @@ bool Stacklist::load(string tag, XML_Helper* helper)
     return false;
 }
 
+Stack* Stacklist::getOwnObjectAt(int x, int y)
+{
+  for (const_iterator it = begin(); it != end(); it++)
+    if (((*it)->getPos().x == x) && ((*it)->getPos().y == y))
+      return *it;
+  return 0;
+}
+
 // End of file
